==> spip_4.0.4.orig.tar.xz: plugins-dist/dump/lang/dump_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la salvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Salvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada salvagardada dins @archive@. Podètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => ' de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permet de salvagardar lo contengut de la basa dins un fichièr que serà servat dins lo repertòri @dossier@.Oblidetz pas tanpauc de recuperar l’integralitat del repertòri @img@, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela salvagarda se poirà restaurar SONQUE dins un sit installat amb la meteissa version d’SPIP. Donc subretot cal pas "voidar la basa" en esperar de reïnstallar la salvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una salvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permet de restaurar una salvagarda 
 de la basa que l’aviatz facha abans. Per aquò faire, cal aver botat lo fichièr que conten la salvagarda 
dins lo repertòri @dossier@.
  Ça que la, siatz prudent(a) amb aquela foncionalitat: <b>las modificacions e pèrdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Salvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Salvagardar la basa'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_lnc.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_lnc
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la salvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Salvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada salvagardada dins @archive@. Podètz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => ' de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Aquela opcion vos permet de salvagardar lo contengut de la basa dins un fichièr que serà servat dins lo repertòri @dossier@.Oblidetz pas tanpauc de recuperar l’integralitat del repertòri @img@, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: aquela salvagarda se poirà restaurar SONQUE dins un sit installat amb la meteissa version d’SPIP. Donc subretot cal pas "voidar la basa" en esperar de reïnstallar la salvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una salvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Aquela opcion vos permet de restaurar una salvagarda 
 de la basa que l’aviatz facha abans. Per aquò faire, cal aver botat lo fichièr que conten la salvagarda 
dins lo repertòri @dossier@.
  Ça que la, siatz prudent(a) amb aquela foncionalitat: <b>las modificacions e pèrdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Salvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Salvagardar la basa',
];
